package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#``@````!````````'```````````0```````
M`+?H(```!P!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0```````"@
M<````````*!P````````H'``````````'``````````<``````````%P```#
M````!`````````(X`````````C@````````".``````````8`````````!@`
M````````"`````$````%````````````````````````````````````````
MH(P```````"@C````````0```````0````8```````"OW````````:_<````
M```!K]P````````#S````````!1$```````!```````"````!`````````-H
M`````````V@````````#:`````````(``````````@``````````"&1TY5$`
M```'````````````````````````````````````````````````````````
M```````09'3E4@````0```````"OW````````:_<```````!K]P`````````
M)``````````D``````````$`````````````````````````````````````
M````````````````````````````````````"````P`"```#````````````
M```!``````$H````````\@`#\@`````````````````````````````````"
M,%`!*````````+```````````````````````````````````````C!0`2@`
M``````"R#P!\``````````````````````````````````(P4`$H````````
M\O\'_``````````````````````````````````",%`!*````````+,___P`
M`````````````````````````````````C!0`2@```````"R`P`$````````
M``````````````````````````(P4`$H````````L```````````````````
M```````````````````",%```````````0````````-"``````````$`````
M```#30`````````/````````!*``````````#````````!@X``````````T`
M``````!AL``````````$````````!6@`````````!0```````!+(````````
M``8````````(J``````````*````````!+X`````````"P`````````8````
M`'```#4```````&L2``````````5`````````````````````P```````;!@
M`````````!$````````7B``````````2`````````(``````````$P``````
M```0`````'````$``````````0````!P```%``````````(`````<```!@``
M`````````````'````H`````````(`````!P```1`````````&P`````<```
M$@`````````9`````'```!,`````````)``````````8````````````````
M;___^P`````(```!````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````&$```!L````
M```````````4````5```````````````6@``````````````*P```#@`````
M````/0```%X````;`````````$8````"````"0```#0````?````"````#$`
M``````````````````!7````(@```#L``````````````!,````D````2```
M````````````'0```#8````J````)P`````````O````/@```#<````6````
M'@```"P`````````/P```!<`````````20```$,`````````3@````\````E
M````9@```"@``````````````$(`````````2P```&`````1````````````
M```P````.@````````!-````)@```#D````````````````````8````(P``
M`!4````@````&0```%@`````````+@````,````````````````````:````
M`````"T````2`````````&L````I````,@``````````````````````````
M````:0``````````````!@``````````````70````````!C````````````
M``````````````````!?`````````$<```!;````$````%````!5````````
M````````````#@````P`````````-0```!P```!!````80````L`````````
M(0```%,```!`````,P`````````'````40``````````````9```````````
M`````````&<````\``````````T``````````````$0```!*````3P``````
M``````````````````!,````10```&H```````````````4`````````````
M`%(``````````````&@```!6`````````````````````````%P```!9````
M"@````````````````````````!B````!````&4`````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````P``"```
M`````!@X``````````````,S$@``"0```````!D``````````EP```1&$```
M"0```````!D```````````````1-$@``"0```````!T``````````$@```.7
M$@``"0```````"ZP`````````$@````J$@``"P```````&&P``````````@`
M``,Y(0````````````````````````````.!$@``"0```````";D````````
M`4@```16$@``"0```````"@L`````````!@```1G$@``"0```````!P(````
M``````````.R$@``"0```````"[X`````````10```0*$@``"0```````#`,
M````````")0```/B$@``"````````!@X``````````@````!$P#_\0``````
M```!``````````````-C$@``"0```````"8,`````````%@```1S$@``"0``
M`````!P```````````````1[$```%0```````;.H``````````````/$$@``
M"0```````"X\`````````'0```-K$@``"0```````#B@````````!)@```/H
M$@``"0```````%G``````````;P```,X$0``````````````````````````
M``0P$0``$0```````;!```````````@```1T$@``"0```````!P`````````
M``````0C$@``"0```````"J@`````````"P```2!$```$0```````;``````
M``````````2($```%0```````;.H``````````````/?$@``"0```````%DX
M`````````(@```07$@``"0```````"K,`````````4````/]$@``"0``````
M`"P,`````````C`````2$0``$@```````;!0``````````````24$```%```
M`````;.H``````````````/2$@``"0```````"A$`````````EP```/S$@``
M"0```````%M\`````````A````2;$```%0```````<0@``````````````0Z
M$@``"0```````#TX`````````*P```"Y$@```````````&&0````````````
M``#`$@```````````&&```````````````#1$@```````````&%P````````
M``````#8$@```````````&%@``````````````"O$@```````````&%0````
M``````````#J$@```````````&%```````````````,/$@```````````&$P
M``````````````#Q$@```````````&$@``````````````,!$@``````````
M`&$0``````````````$%$@```````````&$```````````````"<$@``````
M``````````````````````(,$@```````````&#P``````````````"T$@``
M`````````&#@``````````````$0$@```````````&#0``````````````$6
M$@```````````&#```````````````"+$@``````````````````````````
M``![$@````````````````````````````$G$@```````````&"P````````
M``````!L$@```````````&"@``````````````$M$@```````````&"0````
M``````````$R$@```````````&"```````````````%%(```````````````
M``````````````%?$@```````````&!P``````````````!C$@``````````
M`&!@``````````````+Q$@```````````&!0``````````````%E$@``````
M`````&!```````````````%J(@````````````````````````````&`(@``
M``````````````````````````!4$@```````````&`P``````````````&/
M$0````````````````````````````+Y$@```````````&`@````````````
M``&A$@```````````&`0``````````````,Z$0``````````````````````
M``````,F$@```````````&````````````````!&$@```````````%_P````
M``````````.I$@```````````%_@``````````````&J$@```````````%_0
M``````````````&X$@```````````%_```````````````&_$@``````````
M`%^P```````````````[$@```````````%^@``````````````'/$0``````
M``````````````````````':$@```````````%^0``````````````'A$@``
M`````````%^```````````````,($@```````````%]P``````````````'F
M(`````````````````````````````("$@```````````%]@````````````
M``(+$@```````````%]0```````````````P$@```````````%]`````````
M``````(1$@```````````%\P``````````````(9$@```````````%\@````
M``````````$^$@```````````%\0``````````````(A$@```````````%\`
M``````````````(H$@```````````%[P``````````````(T$@``````````
M`%[@``````````````([$@```````````%[0``````````````,7$@``````
M`````%[```````````````+I$@```````````%ZP``````````````))$@``
M`````````%Z@``````````````)0$@```````````%Z0``````````````)7
M$@```````````%Z```````````````)=(@``````````````````````````
M``)U$@```````````%YP``````````````**$@```````````%Y@````````
M``````*;$@```````````%Y0``````````````*D$@```````````%Y`````
M``````````*K$@```````````%XP``````````````*W$@```````````%X@
M```````````````<$@```````````%X0``````````````*_$0``````````
M``````````````````+,$0````````````````````````````+3$@``````
M`````%X```````````````+A$@```````````%WP````````````7T193D%-
M24-?3$E.2TE.1P!?7U),1%]-05``4&5R;%]S>7-?=&5R;0!?9FEN:0!P97)L
M7W!A<G-E`'!E<FQ?86QL;V,`<&5R;%]D97-T<G5C=`!097)L7W-Y<U]I;FET
M,P!P97)L7W)U;@!P97)L7V-O;G-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`4&5R
M;%]A=&9O<FM?;&]C:P!097)L7V%T9F]R:U]U;FQO8VL`<&5R;%]F<F5E`&=E
M='5I9`!?7W-T86-K7V-H:U]F86EL`'-T<FQE;@!097)L7W-V7S)P=E]F;&%G
M<P!M96UC<'D`<'1H<F5A9%]G971S<&5C:69I8P!097)L7VYE=UA3`&UK9&ER
M`%]?97)R;F]?;&]C871I;VX`<FUD:7(`<F5A9`!097)L7W-A9F5S>7-M86QL
M;V,`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!C;&]S90!E>&ET`%]?<F5G
M:7-T97)?9G)A;65?:6YF;P!?7V-X85]F:6YA;&EZ90!?7W-T86-K7V-H:U]G
M=6%R9`!R96%D;&EN:P!097)L7W-V7W-E='!V`'-T<F-H<@!097)L7V=V7V9E
M=&-H<'8`4$Q?=&AR7VME>0!S=')S='(`;W!E;@!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`8VQO<V5D:7(`;'-T870`<W1R;F-M<`!M96UM;W9E`'5N
M;&EN:P!097)L7VUG7W-E=`!M96US970`4&5R;%]A=E]F971C:`!S=')C;7``
M9V5T<&ED`&QS965K`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`%!E<FQ?8W)O
M86M?;F]C;VYT97AT`%!E<FQ?;F5W6%-?9FQA9W,`<VYP<FEN=&8`86-C97-S
M`%!E<FQ?9V5T7W-V`')E86QL;V,`4$Q?9&]?=6YD=6UP`'-T9&5R<@!097)L
M7V%V7W-H:69T`&]P96YD:7(`<F5A9&1I<@!F<')I;G1F`'-T<FYC<'D`<W1R
M=&]K`'-T<F1U<`!S<')I;G1F`'!T:')E861?871F;W)K`%]?;&EB8U]S=&%R
M=%]M86EN`%]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UM:7!S-C0N
M<V\N,0!X<U]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?8W5R<F5N
M=%]E>&5C7W!R;V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9FEN9'!R;V<`<VAA7VEN
M:70`<VAA7W5P9&%T90!S:&%?9FEN86P`<&%R7VEN:71?96YV`'!A<E]M:W1M
M<&1I<@!P87)?9&ER;F%M90!P87)?8F%S96YA;64`;7E?<&%R7W!L`'!A<E]C
M;&5A;G5P`%]F=&5X=`!?<W1A<G1?8P!P87)?8W5R<F5N=%]E>&5C`%]S=&%R
M=%]D871A`%]?<W1A<G0`7V9B<W,`7V9D871A`%]?8G-S7W-T87)T`%]E9&%T
M80!?96YD`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%````````````
M`````````````````````;``````````$@,```````&P"````````!(#````
M```!L!`````````2`P```````;`8````````$@,```````&P(````````!(#
M```````!L$`````````2`P```````;.@````````$@,`````````````````
M``````````````````````````````````````````````!GO?_@_[P`$/^_
M`!@`````!!$``0`````#@!`E/!P``B><&``#G^`MWYF`:`,@^`D`````!!$`
M`0`````#@!`E/!P``B><%]P#G^`MWYF`^`,@^`D`````W[P`$-^_`!@#X``(
M9[T`(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````&>]_[#_O`!`/!P``@.9X"UGG!=0WYF!\/^E`!#_I@`(KZ0`
M'&>F``AGI0`09Z0`'/^_`$C_L``@_[,`./^R`#`#(/@)_[$`*-^&@6#?A(&(
MWYF"R`#`*"4#(/@)WY""4-^"@S"00@``%$``$]^9@4C?F8)(`R#X"0``````
M0"`EWX*`.!2```3\1,00WYF!V`,@^`DD!``!WYF!H`,@^`D`````WYF!2`,@
M^`F.!```H$`*H=^9@4@#(/@)C@0``(X$``"00P3RWYF!2#1C``(#(/@)H$,$
M\H^D`!R00P3R)(0`!=^9@;`T8P`!``0@^`,@^`F@0P3RWZ4`$`!`."7?@H`X
M)`,`!/Q'P_C<H@``CZ8`'/SB``#?@H!89$)EL/SB``C?@H#HW$(``/SB`!#?
M@H!89$)EN/SB`!C?@H`XK$/$````&"5D8P`!``,0``!&("H4@``Z``,@^-^1
M@#@DP@`$WX6`6-^9@HC>),00``(0^`#B$"T``$`E),8``V2E)F0#(/@)_$#_
M^!1```4`0(`EWYF!R`,@^`G>),00`$"`)=^9@B#>),00`R#X"=^3@%C?A(!8
M9G,@'`)@R"4#(/@)9(1C$!1```_?F8$PWY*`.-Y"Q`@40``%WX2`6`)@R"4#
M(/@)9(1BF/Y"Q`C>1,0($(```]^9@/`#(/@)`````-^9@3`#(/@)WB3$$-^9
M@R@#(/@)`````-^_`$C?O`!`W[,`.-^R`##?L0`H`@`0)=^P`"`#X``(9[T`
M4`"D("TD0@`$W(0````"$/@`XA`M$`#_O/Q$__@`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````01``<``/`E_______]Z[C_______WLL/_______=,8
MW_P```/\X"\#H"`EW^4`$`"\*"W?^0`(`SS(+20!__`#H>@D`R#X"0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!G
MO?_P_[P``#P<``(#F>`M9YP34-^9@AC?B(`@WX>`*(R%``1DA@`(WX2`,/^_
M``@#(/@)``!()=^_``C?O````^``"&>]`!```````````#P#``(`>1@M9&,3
M`-QD@#C<8H!`9(2P6!!$``7<>8)P$R```P`````#(``(``````/@``@`````
M/`8``@#9,"UDQA+(W,2`.-S"@$!DA+!8`$00+P`"&/L``B_^`*,H+0`%*'L0
MH``%W-F!N!,@``,``````R``"``````#X``(`````&>]_]#_O``@/!P``@.9
MX"UGG!)\_[$`"-^1@#C_OP`HDB*SL/^S`!C_L@`0%$``(/^P``#?@H'H$$``
M!-^"@$C?F8'H`R#X"=Q$``#?@H`XWY"`4&1"K_`"`H`O`!"`^]^"@#C?DX`X
M9A#__V12K_#>8K.X`%`8*Q1@`!5D0@`!WYF`6&<Y'5`#(/@)`````-^"@O`0
M0``$WYF"\-^$@#@#(/@)9(2OW"0"``&B(K.PW[\`*-^\`"#?LP`8W[(`$-^Q
M``C?L````^``"&>]`##^8K.X``(0^`)"$"W<60```R#X"0`````0`/_BWF*S
MN&>]__#_O```/!P``@.9X"UGG!&,WX*!X!!```?_OP`(WX6`.-^$@#C?F8'@
M9*6SP`,@^`EDA*_<WYF`6-^_``C?O```9SD=B`,@``AGO0`0````````````
M````9[W_L/^\`$`\'``"`YG@+?^Q`!#_OP!(_[8`./^U`##_M``H_[,`(/^R
M`!C_L``(9YP1,!"``!\``(@EWX*"$-Q4```2@``;`("8)0"@J"4`@#`E)`,`
M/8#"```40``A`-.`+P`0@``"@)`E)!8`/=Y1```2(``/WYF"D`(`,"4"8"@E
M`R#X"0(@("440``9`C`0+8!"```45@`6``````)4D"\`$I#[9A```:ZR```"
M,(@MW[\`2-^\`$#?M@`XW[4`,-^T`"C?LP`@W[(`&-^P``@"(!`EW[$`$`/@
M``AGO0!0$$/_WP`````0`/_:9,8``1``_]YF4@`(9[W_T/^\`"`\'``"`YG@
M+6><$#3_L``8WYF`6-^0@?C_OP`HW@(``&>E``1G.1\@_Z(`"`,@^`D`````
MWZ0`"-X#```0@P`$W[\`*-^9@1@#(/@)`````-^\`"#?L``8`^``"&>]`#!G
MO?^P_[P`0#P<``(#F>`M9YP/S-^"@?C_LP`X_[(`,/^Q`"C_L``@_[\`2-Q#
M``#?D8!8WY."$/^C`!@`0(`E9[(`%&8Q'R`"0"@E`B#()0,@^`G_I``(%$``
M"-^D``C?HP`8W@(``!!B``W?OP!(WYF!&`,@^`D`````CZ(`%``"&/C>8@``
M`$,0+=Q#``@08/_M_$,``!``__QD0@`(W[P`0-^S`#C?L@`PW[$`*-^P`"`#
MX``(9[T`4&>]_Z#_O`!0/!P``@.9X"UGG`\0_[,`,-^3@?C_L0`@_[``&/^_
M`%C_M@!(_[4`0/^T`#C_L@`HWF(``("C``#_H@`()`(`/0"`B"448@`"`*"`
M)62P``'?F8$@`R#X"0(`("7?F8!89Z4`!`(@("5G.1\@`R#X"0!`H"400``4
M`$"0)=^9@2`#(/@)`$`@)0!4$"L40``V`B`8)8("``!F$``!9E(``11`__RB
M0O__```0)=^D``C>8P``$(,`5]^_`%C?F8$8`R#X"0````#?E8(0``"0)=ZV
M```"P!`EW$,``!1@``YD0@`(WX*`."9$``*,0\/P$&``"P`$(/C?F8,@`(`H
M)0,@^`D"P"`E%$``$/ZB```0`/_F)`+__Q``_^\F4@`!WYF"H"0#``$#(/@)
MK$/#\!!`__<`0"`EWYF"F``2,/@#(/@)`L`H)?ZB``#>H@``9D,``0`#&/@`
M0Q`M_$```*^R``0"(!@E)`0`/8!B```00``#C[(`!!1$`"0`````WY6"$`!Q
M&"_?F8*@``,8`&:$``(`$A#X`(,@+=ZR```#(/@)`D*0+1!`_]G^0@``CZ(`
M!"0%`#T``ACXWJ(```!#$"W<0@``@B,``&8Q``&@0P```$`@)1!@``-D0@`!
M%&7_^0`````D`P`]H(,``((#``!F$``!9$(``11@__R@0___$`#_J0``$"40
M`/_79&,``=^\`%#?M@!(W[4`0-^T`#C?LP`PW[(`*-^Q`"#?L``8`^``"&>]
M`&!GO?[`_[P!,#P<``(#F>`M9YP,S/^S`0C?DX'X_[\!./^W`2C_M@$@_[4!
M&/^T`1#_L@$`_[$`^/^P`/#>8@``_Z(`Z!"``!D`````@((``!!``!8`@(@E
MWYF#2`,@^`D`````$$``$0!`D"7?E(!8WY6`6-^6@%AFE&(P9K4CA-^9@M`#
M(/@)`D`@)11```[?F8+8WYF">`,@^`D"0"`EWYF!F`,@^`D"("`EWZ,`Z-YB
M```08@`]W[\!.-^9@1@#(/@)`````&10`!,"@"@E`R#X"0(`("400/_JWYF"
MT-^9@MAFQ6(X`R#X"0(`("400/_DWYF"T-^9@2`#(/@)`B`@)=^9@2`"`"`E
M`R#X"0!`N"7?F8*@`N(0+0`"(``#(/@))(0``M^%@%C?F8%``$`@)0(`."4"
M(#`E9*5B0`,@^`G_H@`(WZ0`"-^9@6@#(/@)9Z4`&"0#__\08@`.WZ0`"(^B
M`#@D`T``,$+P`!1#``D``````J#()0,@^`D`````WYF!<`,@^`G?I``($`#_
MO-^9@M#?F8*H`R#X"?^D``@0`/_W`````-^\`3#?MP$HW[8!(-^U`1C?M`$0
MW[,!"-^R`0#?L0#XW[``\`/@``AGO0%`9[W_`/^\`/`\'``"`YG@+6><"O3_
ML`#@WY"!^/^Q`.C?F8*`_[\`^-X"``!GI0`(`("()?^B`-@#(/@)`````!1`
M`!2/HP`H)`5``#!C\``090`$`&`@)30#H``4@P`&`````-^9@Q`D!0`"`R#X
M"0(@("4L0@`!WZ0`V-X#```0@P`&W[\`^-^9@1@#(/@)`````!``__@``!`E
MW[P`\-^Q`.C?L`#@`^``"&>]`0!GO?_P_[P``#P<``(#F>`M9YP*1-^"@E#_
MOP`(WYF!2`,@^`F,1```WX>`<-^%@%C?AH&0WYF!6&3GH%ADI6)(`R#X"0!`
M("7?OP`(W[P```/@``AGO0`09[W_X/^\`!`\'``"`YG@+6><">S_L``(WY""
M4/^_`!C?F8%(`R#X"8X$``#?F8!X`R#X"0!`("7?F8%(`R#X"8X$``#?B(!8
MWX6`6-^&@(#?F8,`90AEJ```2"4!`#@E9*5B:`,@^`D`0"`EW[\`&-^\`!#?
ML``(`^``"&>]`"!GO=^@_[P@4#P<``(#F>`M9YP);/^S($C?DX'XWYF"X/^_
M(%C_LB!`_[$@./^P(##>8@``_Z(@*`,@^`D`````WXB`6-^&@%C?F8,(9Z0`
M&&4(8H``0#@E9,9BB"0%$`$#(/@)_Z0`""0#__\40P`)WZ0`"```("7?HR`H
MWF(``!!B`"G?OR!8WYF!&`,@^`D`````+$,0`01L```$0/_UWYF""&>Q$"`D
M!A```R#X"0(@*"4``H``!@#_[@(`D"7?F8*@`R#X"28$``$00/_I`$`@)0!1
M$"L00``$`B00*P"2$"T"(@`S`B00*Q!```3?F8$X`C`0+0""`#/?F8$X`@`P
M)0(@*"4J4A`"!DP```,@^`D``````%"`+0!`("40`/_5H@```-^\(%#?LR!(
MW[(@0-^Q(#C?L"`P`(`0)0/@``AGO2!@/`,``@!Y&"UD8P@DW'F`B`,@``@`
M````9[WNL/^\$3@\'``"`YG@+6><"`S_M!$8_[`0^-^4@?@`@(`EWYF`6-^$
M@%C_OQ%(_[41(/^S$1#_OA%`_[<1,/^V$2C_LA$(_[$1`-Z"``!DA&*89SD@
M'`"@F"7_HA#H`R#X"0````#?F8(X)`4`+P(`("4#(/@)`$"H)1!```[?F8$@
MWX2`6-^9@%@"`"@E9SDA0`,@^`EDA&*HWZ,0Z-Z"```08@!@W[\12-^9@1@#
M(/@)``````(`("4#(/@)WY*`6-^9@5!F16*X`F`@)0,@^`D``H@`WY:`6-^7
M@%@`0/`EWX*`6&;68C!F]V+`_Z(`"!/`_^3?A(!8@\(``!1```(``````L#P
M)1*@``S?F8+8`\`H)0,@^`D"H"`E%$``"-^9@2#?F8%09D5BN`,@^`D``"`E
M$`#_[@!`\"7?F8$@`R#X"0/`("4D`P`O``(0``/"("V`A/__$(,`%``````F
M(P`!`&(0(2A"$``00/_$WZ(`"-^9@PAGLP#H`@!()0+@0"4#P#@E9$9BR"0%
M$``#(/@)`F`@)21"``$L0A`!%$``!M^9@6@````T)$+__P/"("T0`/_GH(``
M`&>E`!@#(/@)`F`@)11`_]:/H@`X-`.``#!"\``40__3WYF!4-^9@Q`D!0`!
M`R#X"0)@("440/_-WYF!4-^$@%C?F8!8`F`H)6<Y(4`#(/@)9(1BJ-^9@F@#
M(/@)`F`@)1``_YX`0(`EW[X10-^\$3C?MQ$PW[81*-^U$2#?M!$8W[,1$-^R
M$0C?L1$``@`0)=^P$/@#X``(9[T14`"`$"4D!0`O@(,``!1@``,``````^``
M"``````49?_Z9(0``1``__@`@!`E9[W_X/^\`!`\'``"`YG@+?^_`!C_L``(
M$(``!&><!82`@@``%$``"P"`@"7?A(!8WYF":&2$8C`#(/@)`````-^_`!C?
MO``0W[``"`/@``AGO0`@WYF!(`,@^`D`````)`,`+V1"__\"`A`M`@(@*Q"`
M`"<`````@$0``!"#`!\D!``O@$4```!`&"44I``=9$+__P!@$"4D`P`O9$+_
M_P("("L0@``&`%`P+X!$```0@__[9$+__V1"``$`4#`O9,,``BQC$`$08/_=
M```0)0(`*"7?D(`XWYF"`&3&``%F!+/P+,(0`01,```#(/@)`````!``_])F
M`K/P$`#_VV1"__\"`A@K%&#_W@`````6`O_B)`,`+X(#```D`@`O%&(`!-^9
M@FC?A(!8$`#_PF2$8C#?A(!8$`#_OV2$8L!GO?^`_[P`<#P<``(#F>`M9YP$
M1/^S`%#?A8!PWY.!^/^_`'C?F8$X_[8`:/^U`&#_M`!8_[(`2/^Q`$#_L``X
M)`8`(F2EH##>8@```Z`@)=^0@%C_H@`H`R#X"680((3?A(!8`@#()62$8M`#
M(/@)WY2`6-^$@%@"`,@E9(1BX`,@^`G?E8!8WX2`6`(`R"5DA&+H`R#X"=^2
M@%C?A(!8`@#()62$8O@#(/@)WY:`6`(`R"5FA&,``R#X"=^1@%C?A(!8`@#(
M)62$8Q`#(/@)9C$@'`(`R"4#(/@)9J1BF`(`R"4#(/@)9D1C(`(`R"4#(/@)
M9L1C,-^$@%@"`,@E`R#X"62$8T#?A(!8`@#()62$8J@#(/@)WY"`6-^$@%@"
M(,@E9(1C4`,@^`EF$"%`$$``!`(`R"4`0"@E`R#X"6;$8S#?A(!8`B#()0,@
M^`EDA&-H$$``!0!`*"7?A(!8`@#()0,@^`EDA&(`WX2`6`(@R"4#(/@)9(1C
M@&:D8I@40``(`$`H)=^$@%@"(,@E`R#X"62$8Y`00``1`$`H)69$8R`"`,@E
M`R#X"0````#?A8!89H1C``(`R"4#(/@)9*5CN-^C`"C>8@``$&(`#M^_`'C?
MF8$8`R#X"0````#?A8!8WYF"D"0&``IDI6.H`R#X"6>D`!$40/_M9Z4`&Q``
M_^AF1&,@W[P`<-^V`&C?M0!@W[0`6-^S`%#?L@!(W[$`0-^P`#@#X``(9[T`
M@&>]_^#_O``0/!P``@.9X"UGG`(4_[``"-^0@#@D`O__C@.P,!1B``W_OP`8
MWX2`6-^9@%AG.2`<`R#X"62$8R`00``%```8)8!"```00``".$(`,``"&"NN
M`[`PW[\`&(X"L##?O``0W[``"`/@``AGO0`@9[W_\/^\```\'``"`YG@+6><
M`:#?F8$0_[\`"`,@^`D`````WYF"*`,@^`D`0"`E$$```M^_``C<0@``W[P`
M``/@``AGO0`09[W_T/^\`"`\'``"`YG@+6><`5C_LP`8WYF`6-^3@%C_L0`(
M9SD@'`"`B"5F9&/`_[\`*/^R`!`#(/@)_[````)@("400``%`B`H)0!`@"6`
M0@``%$``#-^9@EADA&/`WYF`6-^_`"C?O``@W[,`&-^R`!#?L0`(W[```&<Y
M(4`#(``(9[T`,`,@^`D"`"`E%$``&=^_`"C?F8$@`R#X"0(@("7?F8$@`@`@
M)0,@^`D`0)`EWYF"H`)"$"T#(/@)9$0``M^'@%C?A8!8WYF!0&2E8L@`0"`E
M`@!`)63G8K@"(#`E`R#X"0!`D"4"0"@E$`#_VV9D8\#?O``@W[,`&-^R`!#?
ML0`(W[````/@``AGO0`P9[V`$/^\?]@\'``"`YG@+6><`$3_L7^@WY&!^/^_
M?^C_MG_(_[5_P/^T?[C_L'^8_[Y_X/^W?]#_LW^P_[)_J&>]_@``@*@E9Z0`
M$-XB```T`X%X`&08+?QB```T`H&``$00+3P0__\`4(`MWX*`6-^%@#AD0F/8
MWYF!./X"?H#?@H!8)`8`,&2EL`!F!'ZP9$)B,/X"?H@#(/@)_@!^D-^"@%C?
MEH!89$)CX-^4@%C^`GZ89M8@'-^"@%AFA&*8`L#()61"8^C^`GZ@`R#X"?X`
M?J@00``7_[$`"`!`@"6`0@``$$``%-^9@)#?F8"8`R#X"0(`("7?F8)H`R#X
M"0(`("4`0(`E9Z,`$#0"@7@`0Q`MW$,``-^B``C<0@``$&(!S@(`$"7?F8$8
M`R#X"0````#?F8"0`R#X"0`````40``:`$"`)3P1__\T`H&`9Z,`$&8Q?I@`
M0Q`M`%&(+=XD```4@``$`L#()=^0@%@0```.9A!CT`,@^`D`````%$```P!`
M("40`/_U9C$`"(!"```00/_\WYF":`,@^`D`````$$#_^`!`@"7?F8$@`@`@
M)0,@^`G?DX!8WYF"H``"('ADA``!`R#X"69S8_@`0)`E`$"()8(&```4P`!;
MWYF!0-^3@%@\$?__-`*!@&>C`!!F,7ZP`$,0+0!1B"UF<R5<WC```!(``!`"
MP,@E`R#X"0(`("400`!3`$"`)8!"```00`!0`F#()0,@^`D"`"`E$$#_\V8Q
M``C?F8)H`R#X"0(`("4`0(`EWY>`6#P1__\T`H&`9Z,`$&8Q?H``0Q`M`%&(
M+6;W)5P6```(WYF!(-XS```28``%`````()B```40``Z`N#()=^9@2`#(/@)
M`@`@)=^9@2`"0"`E`R#X"0!`B"7?F8*@`B(@+0`$(``DEP0$`R#X"0+@("4"
M0$@EWXB`6-^2@%C?A8!8WYF!0&4(9`!F1V+``@`P)62E9`@`0"`E`R#X"0!`
MB"7?F8%X)`4!P`,@^`D"("`E)`/__Q1B`"/?F8&``R#X"0````",2```)`(`
M$1$"`!YGHP`0WX*#.-^%@%C>I@``W$0``-^9@=`"(#@E`R#X"62E9!@0`/]P
M``"`)0(@("4PQ@#_`F`H)0,@^`EF$``!$`#_G68Q``(0`/^F9C$`"`,@^`D"
M8"`E$$``!-^9@F@#(/@)`F`@)0!`@"40`/^W9C$`"&>C`!`\$/__-`*!@-^9
M@H``0Q`M9@5^X`!%*"T#(/@)`B`@)1!```L`0)@EWX*#.-^%@%C>I@``W$0`
M`-^9@=`"(#@E`R#X"62E9%@0`/_8`````&>C`!`T`H&``$,0+0!0@"V.`G\`
M)`-``#!"\``40__OWX*#.-^9@1`#(/@)CAY_"``"$``7PO_IWX*#.(X"?P`D
M`P'`,$(!_Q1#_^3?@H,XWYF"H`,@^`D"X"`EWX2`6`+`R"5DA&2P`R#X"0!`
M@"440`!_`$`@)=ZV``#?F8$@`R#X"0+`("4``A```$"X)2A"``040``CWYF`
MH-^%@%C?F8+89N3__&2E9+@#(/@)`L0@+11``!O?F8"@)`(`!!+B``8F]__\
M`M>X+8+C__\D`@`O%&(`$P````#>M0`($J``#]^9@2`#(/@)`J`@)2Q#``04
M8``+WYF`H-^%@%C?F8+89$+__&2E9,`#(/@)`J(@+11```/?F8"@`J"P)=^9
M@*`#(/@)`````!1``*'?A8!8WYF"8```*"4#(/@)`L`@)1!``)H`0*@EWYF"
MZ"0&``(D!?_N`$`@)0,@^`D\$___9Z,`$#0"@8``0Q`M9G9_^`!6L"W?F8&H
M)`8`!@+`*"4#(/@)`J`@)6>C`!`T`H&``$,0+0!3$"V00W_X%&``/M^9@NB0
M0W_Y)`0`0Q1D`#L``#`ED$5_^B0$`$$4I``W`````)!$?_L4@P`T)`,`2)!$
M?_P4@P`R```H)9!#?_TD`@!%%&(`+@`````D!@`")`7_Q@,@^`D"H"`EWYF!
MJ"0&`"D"P"@E`R#X"0*@("7?B8!8`L!`)64I9:C?A8!8WYF!0&9'8L`"(#`E
M9*5DR`,@^`D"`"`EWYF!<`,@^`D"("`EWYF`6`(`*"5G.2%``R#X"6:$8IC?
MF8"8`R#X"0(`("40`/ZN9Z,`$-^9@F@#(/@)WK8``-^9@*@"P"`E`R#X"0!`
M*"440/][`$"P)1``_WG>M@`````P)0``*"4"H"`E`R#X"3P3___?F8"P`R#X
M"69W?_AGHP`0`$"P)30"@8``0Q`M`%>X+=^9@:@T!H```N`H)0,@^`D"H"`E
M``(P`!S``"S?F8"XWYF!P`*@("4#(/@)9G-_L&>C`!`T`H&``$,0+0!3N"W?
MF8#``L`H)0+@("4#(/@)WYZ`6#0"@8!GHP`09G,`&`!#$"T`4Y@M``"P)3P5
M__]GWF/X`O80+=^9@4"01@```F`@)0/`*"4#(/@)9M8``20#`!06P__W9G,`
M`F>C`!`T`H&``$,0+0!5$"W?B8!8H$!_\#0"@8!FJ'_(`$,0+64I9:@0`/^B
M`$A`+0+@*"4#(/@)`L`@)1``_\K?F8&HWX6`6-^$@%C?F8!89*5CN&2$8R!G
M.2%``R#X"=^5@%C?F8+@WY:`6`,@^`DD'O__WX6`6-^9@4!FJ66H`$!`)69'
M8L`"(#`E9*5DV`(`("4D%P`19K5EJ`,@^`EFUF3HWYF!>"0%`<`#(/@)`@`@
M)1?"_X;?F8&``R#X"0````",0@``%%?_@=^9@N`#(/@)`````-^9@4`F:0`!
M`J!0)0!`0"5F1V+``B`P)0+`*"4"`"`E`R#X"0$@F"40`/_IWYF!>&>]`@#?
MOW_HW[Y_X-^\?]C?MW_0W[9_R-^U?\#?M'^XW[-_L-^R?ZC?L7^@W[!_F`/@
M``AGO7_P9[W_D/^\`%@\'``"`YG@+6><][#_L``8WY""4/^_`&C_L@`H_[$`
M(/^^`&#_MP!0_[8`2/^U`$#_M``X_[,`,-^9@4B.!````R#X"=^2@%B.!```
MWYF!2`!`B"4#(/@)9E(@'-^$@%B2(P"X9(1C``)`R"4#(/@)H$,`N1!```<D
M`P`Q@$0``!2#``7?F8#(@$(``1!```7?F8%(WYF`R`,@^`D`````WYF!2`,@
M^`F.!```WX6`6-^9@D`D!P`+)`8``62E90`#(/@)`$`@)11``"K?EH`XWYF!
M2`,@^`F.!```WX6`6-^9@D`D!P`#)`8``62E90@#(/@)`$`@)11``&D`0(@E
MWYF!2`,@^`F.!```WX6`6-^9@D`D!P`#)`8``62E91@#(/@)`$`@)1!``(D`
M0(@EWX2`6`)`R"4#(/@)9(1BJ!!``'$`0)@EWYF!2`,@^`F.!```WB,`$`)@
M,"7<90``WYF",`,@^`D`0"`E$```>`````#<0@`0/!,`(-Q5`"C?GH`X)!$`
M`0+`H"4F<P0`CL+$`(X$```"(A`J)B;__Q!```PF-___WYF!2`,@^`FOI@``
MCZ8``-^9@L```#@E`J`H)0,@^`D`0"`E%$``!P!`&"6.@L0`)$+__Q17_[W?
MF8%($```*"01``'?Q,/X`!$0^`""$"W<9```W$@``(R"``PD!00``%,0)!1%
M``G?F8%(W(4`$-^9@M@#(/@)`0`@)11`_^R.@L0`$`#_V"8Q``&.!```_Z@`
M``,@^`G_HP`(WZ,`"-^9@2C<90``)`<``@``,"4#(/@)`$`@)=^H```0`/_L
M`$`H)=^9@4@#(/@))C$``=^9@T`"H"@E`R#X"0!`("6.@L0``B(0*A1`__:.
M!```$`#_CM^9@4C?F8%(`R#X"8X$``#>(P`0WX:`6-QE``#?F8(P`$`@)0,@
M^`EDQF40WB(`$-Q"``",0@`,``(5@C!"``$00/^(WYF!2`,@^`F.!```WB,`
M$-^9@K#<90```R#X"0!`("40`/^`WYF!2-^9@(@#(/@)`````(X$``#?F8%(
M$$``-0!`F"4#(/@)`````-XC`!#?F8(PW&4```!`("4#(/@)`F`P)=^9@7`#
M(/@)`F`@)=^9@4@#(/@)C@0``(X$``#?F8%(`R#X"0!`B"7?A8!8WYF#&"0&
M``%DI64@`R#X"0!`("7?AH!8WYF",&3&93@`0"@E`R#X"0(@("6.!```WYF!
M2`,@^`G?D(`XWX2`6`)`R"5DA&*8`R#X":!``+D"`(@E%$``$OX"Q`C?@H`X
MWYF`T`,@^`G<1,/X%$``#/X"Q`C?A(!8WYF"^`,@^`EDA&5``R#X"0````#?
M@X`XW&3#^-XC`!`0`/]4W(8``-^9@7C>),0(`R#X"20%`<``0#@E)`(`$1#B
M``PDX@`!+$(``A1```K?OP!HWX*`.-^$@%C<0L/XWB;$"-Q%``#?F8+X`R#X
M"62$96C?OP!HW[X`8-^\`%C?MP!0W[8`2-^U`$#?M``XW[,`,-^R`"C?L0`@
MW[``&`/@``AGO0!P9[W_X/^\`!`\'``"`YG@+6><\QC?F8#8_[\`&/^Q``C_
ML````R#X"0"`@"7?F8#@`R#X"0!`("7?F8"@`R#X"0!`B"400``4W[\`&!(`
M`!(`````@@(``!!```_?A8!8WYF"6&2E9``#(/@)`B`@)18B``G?OP`8WYF`
M6-^\`!#?L0`(`@`@)=^P``!G.2.$`R``"&>]`"#?O``0W[$`"-^P```#X``(
M9[T`(````````````````&>]_3#_O`+`/!P``@.9X"UGG/)@WXF!^/^_`LC_
MM0*X_[0"L/^S`JC_L@*@_[$"F/^P`I#=(@``9(,`./^B`HAGH@`(9(<`>`!`
M*"7<9@``9&,`"``&0#X`!C`\``8P/ORH``#\I@`(%./_^&2E`!!D1@(`W$4`
M0-Q#`&AD0@`(`&48)MQ%``@`91@FW$7_^`!E&"8``RAX``,?^@"C&"4``Q@\
M``,8/A1&__+\0P!XW(T``#P%6H(`#1;Z``UQ>`'"<"7?H@`(9*5YF=R,`"#<
MB``0W(H`&`!%$"T`#G`\W(L`"`!,$"T`#G`^`<)P+0$*$"8`2Q`D`$H0)@'"
M<"T`"Q^X``L0N@!B$"4``H@\`!&(/M^C`!`!$3@F``[`/`!E&"T`[3@D`!C`
M/@!J&"T`Z#@F`.,X+0`8,7@`&![Z`,,P)0#F."T`#1BZ``TWN`##&"4`0S`F
MWZ(`&`#8,"0`11`M`$@0+0#1,"8`PC`M)`(``0`"$7QD0O_@``?(/``'<7@`
M!S[Z`<)P)##G`!\!QS@E`,<P+0`8<+H`&#^X`.YP)=^G`"``&<@^`.4X+0`#
M>#P`;A@F`/&(+0`/>#X`!H`\`'D8)``&.7@`!C;Z`.(X)`!O&"8PQ@`?`.8P
M)0!Q&"T`9A@M`!D_N-^F`"@`&<BZ`/DX)0`0@#X`Q3`M``[`/`''<"8`SW@M
M`!C`/@`#B#P!T'`D``,Q>``#'OH`PC`D`=AP)C!C`!\`PQ@E`<]P+0'#<"T`
M$#>XWZ,`,``0@+H`T#`E`!&(/@!E&"T`!\@\`.8X)@!XP"T`&<@^``Z0/`#Q
M."0`#AEX``YV^@!B&"0`^3@F,<X`'P!N<"4`^#@M`.XX+0`1'[C?K@`X`!&(
MN@!Q&"4`$I`^`<5P+0`&@#P`PS`F`=G(+0`0@#X`!W@\`-(P)``'<7@`!S[Z
M`<)P)`#0,"8PYP`?`<<X)0#9,"T`QS`M`!)WN-^G`$``$I"Z`=)P)0`/>#X`
MY3@M``/`/`!N&"8`\(`M`!C`/@`&B#P`;Q@D``8Y>``&-OH`XC@D`'@8)C#&
M`!\`YC`E`'`8+0!F&"T`#S^XWZ8`2``/>+H`[S@E`!&(/@#%,"T`#L@\`<=P
M)@#8P"T`&<@^``.`/`'1<"0``S%X``,>^@#","0!V7`F,&,`'P##&"4!V'`M
M`<-P+0`1-[C?HP!0`!&(N@#1,"4`$(`^`&48+0`'>#P`YC@F`'G(+0`/>#X`
M#L`\`/`X)``.&7@`#G;Z`&(8)`#O."8QS@`?`&YP)0#Y."T`[C@M`!`?N-^N
M`%@`$("Z`'`8)0`8P#X!Q7`M``:(/`##,"8!SW@M`!&(/@`'R#P`V#`D``=Q
M>``'/OH!PG`D`-$P)C#G`!\!QS@E`,\P+0#',"T`&'>XWZ<`8``8P+H!V'`E
M`!G(/@#E."T``X`\`&X8)@#QB"T`$(`^``9X/`!Y&"0`!CEX``8V^@#B."0`
M<!@F,,8`'P#F,"4`<1@M`&88+0`9/[C?I@!H`!G(N@#Y."4`#W@^`,4P+0`.
MP#P!QW`F`-"`+0`8P#X``X@\`<]P)``#,7@``Q[Z`,(P)`'8<"8P8P`?`,,8
M)0'0<"T!PW`M``\WN-^C`'``#WBZ`,\P)0`1B#X`91@M``?(/`#F."8`>,`M
M`!G(/@`.@#P`\3@D``X9>``.=OH`8A@D`/DX)C'.`!\`;G`E`/@X+0#N."T`
M$1^XWZX`>``1B+H`<1@E`!"`/@'%<"T`!G@\`,,P)@'9R"T`#W@^``?`/`#0
M,"0`!W%X``<^^@'"<"0`SS`F,.<`'P''."4`V3`M`,<P+0`0=[C?IP"``!"`
MN@'0<"4`&,`^`.4X+0`#B#P`;A@F`.]X+0`1B#X`!L@\`'@8)``&.7@`!C;Z
M`.(X)`!Q&"8PQ@`?`.8P)0!O&"T`9A@M`!@_N-^F`(@`&,"Z`/@X)0`9R#X`
MQ3`M``Z`/`''<"8`T8@M`!"`/@`#>#P!V7`D``,Q>``#'OH`PC`D`=!P)C!C
M`!\`PQ@E`=%P+0'#<"T`&3>XWZ,`D``9R+H`V3`E``]X/@!E&"T`!\`\`.8X
M)@!P@"T`&,`^``Z8/`#O."0`#AEX``YV^@!B&"0`^#@F,<X`'P!N<"4`\#@M
M`.XX+=^N`)@`#Q^X`<5P+0`/>+H`;Q@E`=C`+0`'D#P`!W%X``<^^@`3F#X!
MPG`D``;(/##G`!\`PS`F`!G(/@#3,"0!QS@E`-DP)@`'.#P`V#`M``<X/@`3
MA[@`$YBZ`,<P+0(3@"7?IP"@`!*0/@`#>#P`<!@F``]X/@`&B#P`<A@D`.4H
M+0`1B#X`;Q@F`+DH+0!E*"T`$3[Z`!$9>`!G&"4`$L>X`!*0N@,2P"4``Q@\
M`A@X)@`#&#X`HQ@M`.8X)CP%;MG?I@"H-*7KH0`#H#P`%*`^`,4P+0#/>"T`
M%';Z`!0Q>`#.,"4`!S@\`!'/N``'.#X`$8BZ``8P/`,QR"4`[S@M``8P/@#F
M."W?K@"P`QDP)@##&"8`$(`\``>0/`'%<"T`$(`^``,8/``2D#X!T'`M``,8
M/@`2-OH!PQ@M`!)Q>`'&<"4`%(^X``YP/``4H+H"-(@E``YP/@!N&"W?I@"X
M`S%P)@''."8`&,`\``.8/`#%,"T`&,`^``<X/``3F#X`V#`M``<X/@#',"T`
M$WEX`!,^^@'G>"4`$L>X`!*0N@,2P"4`#W@\`C@X)M^N`,``#W@^`,\P+0#C
M&"8`&<@\``:`/`'%<"T`&<@^``,8/``0@#X!V7`M``,8/@'#<"T`$#EX`!`>
M^@#C."4`$\^X`!.8N@,SR"4`!S@\`QD8)M^O`,@`!S@^`<=P+0!F,"8`$8@\
M``Z0/`'E>"T`$8@^``8P/``2D#X!\7@M``8P/@'F>"T`$AEX`!(V^@!F&"4`
M`Q@\``,8/@'C>"T`$(^X`!"`N@(PB"4`#Y@\`!.8/@,Q&";?IP#0`&YP)@`3
M,7@`$Q[Z`!C`/`#E."T`&,`^`,,P)0`.<#P`^#@M``YP/@`&,#P`[C@M``8P
M/@#F."T`$L>X`!*0N@,2P"4`!X`\`!"`/@(X,";?HP#8`,]X)@`0<7@`$#;Z
M`!G(/`!E&"T`&<@^`<9P)0`/>#P`>1@M``]X/@`3S[@`#G`\`!.8N@,SR"4`
M;Q@M``YP/M^F`.``;A@M`QEP)@''."8`$8@\``.0/`#%,"T`$8@^``<X/``2
MD#X`T3`M``<X/@#',"T`$GEX`!(^^@'G>"4`$(^X`!"`N@(PB"4`#W@\`S$X
M)M^N`.@`#W@^`,\P+0#C&"8`&,`\``:8/`'%<"T`&,`^``,8/``3F#X!V'`M
M``,8/@'#<"T`$SEX`!,>^@#C."4`$L>X`!*0N@,2P"4`!S@\`C@8)M^O`/``
M!S@^`<=P+0!F,"8`&<@\``Z`/`'E>"T`&<@^``8P/``0@#X!^7@M``8P/@'F
M>"T`$!EX`!`V^@!F&"4``Q@\``,8/@'C>"T`$\^X`!.8N@,SR"4`#Y`\`!*0
M/@,9&";?IP#X`&YP)@`2,7@`$A[Z`!&(/`#E."T`$8@^`,,P)0`.<#P`\3@M
M``YP/@`&,#P`[C@M``8P/@`0C[@`$("Z`C"()0#F."W?HP$``S$P)@`'F#P`
M$Y@^`,]X)@`8P#P`$S;Z`&48+0`8P#X`$W%X``]X/`!X&"T`#W@^`<9P)0!O
M&"T`#G`\`!)_N``2D+H!\G@E``YP/@!N&"W?I@$(`B]P)@''."8`&<@\``/`
M/`#%,"T`&<@^``<X/``8P#X`V3`M``<X/@#',"T`&(%X`!@^^@('@"4`$S^X
M`!.8N@#S."4`$(`\`>?()M^N`1``$(`^`-`P+0,C&"8`$8@\``:0/`'%<"T`
M$8@^``,8/``2D#X!T7`M``,8/@'#<"T`$LEX`!(>^@,CR"4`&(^X`!C`N@(X
MB"4`&<@\`/$8)M^P`1@`&<@^`=EP+0!F,"8`#W@\``Z8/`(%@"T`#W@^``8P
M/``3F#X"#X`M``8P/@(&@"T`$QEX`!,V^@!F&"4``Q@\``,8/@(#@"T`$L>X
M`!*0N@,2P"4`$*@\`!6H/@(X&";?N0$@`&YP)@`5>7@`%1[Z``<X/`,ER"T`
M!S@^`>-X)0`.<#P#)\@M``YP/@`/>#P#+L@M``]X/@,OR"T`$Y>X`!.8N@)3
MD"4`&:`\`!2@/@,2,";?HP$H`-"`)@`4.7@`%#;Z`!&(/`!E&"T`$8@^`.8X
M)0`0@#P`<1@M`!"`/@`'.#P`<!@M``<X/@!G&"T`%8^X`!6HN@(UB"4``Y@\
M`!.8/@)1,";?KP$P`!,^^@#9R"8`&,`\`!,Q>`'E>"T`&,`^`,<P)0`9R#P!
M^'@M`!G(/@`4=[@`!C`\`!2@N@'4<"4!^7@M``8P/@'F>"W?IP$X`BXP)@##
M&"8`$I`\``^`/`#E."T`$I`^``,8/``0@#X`\C@M``,8/@#C."T`$#;Z`!`9
M>`!F&"4`$Y>XWZ8!0``3F+H"4Y`E`,4P+0'2*"8`KW@F`!&(/`#C&"T`$8@^
M``]X/``#*7@`T3`M``]X/@#/,"T`HG@D``,N^C"E`!\!Y2@E``/(/``0'[@`
M$("Z`,4P+0!P&"4\!2/&WZ\!2``#@#PTI>\W``4HN``9R#X`$(`^`D/`)0`.
M<#P!Y7@M`!(X/`,9P"0"4)`D``YP/@'N<"T#$L`E``:(/`,.P"T`!G%X``8V
M^@'"<"0PQ@`?`<8P)0`9=[@`&<BZ`=EP)0`1B#X`;A@E`=!X)`!Q&"0`;Q@E
MWZ\!4``'.#X!Y7@M`P;`+0'G."T`9Q@M`!B0/``8.7@`&,;Z`.(X)#,8`!\`
M^,`E`'C`+=^C`5@`$3^X`&48+0`1B+H`\3@E`'"`+0`8R#P`&!EX`!C&^@`2
MD#X!QW@E`&(8)#,8`!\`>,`E``>(/`'R>"0`$A^X`!*0N@!R&"4`$8@^`!G(
M/@`.,#P`XS@E`=%P)`'N>"4`^3@D`'%P)`#N."7?K@%@`?!X+0'%<"T`!C`^
M`?AX+0'&,"T`#X`\`.8X+0`/,7@`#W[Z`,(P)#'O`!\`SW@E`!DWN``9R+H`
MV3`E``;(/``0@#X`&<@^`&9P)0`#P#P!T'`D`'D8)`'#<"7?HP%H`.\X+0!E
M&"T`<8@M``>0/``'&7@`!S[Z`&(8)##G`!\`9S@E`!`?N``0@+H`<!@E`!*0
M/@'1<"T`PS`E`<=P+0#2,"0`>3@D`,<P)=^G`7``&,`^`.4X+0#XP"T`#H@\
M``XY>``.=OH`XC@D,<X`'P#N<"4`$C^X`!*0N@#R."4`V#`M``?`/``1B#X`
M&,`^`&=X)0`#@#P!\7@D`'@8)`'C>"7?HP%X`,XP+0!E&"T`><@M``:8/``&
M&7@`!C;Z`&(8)##&`!\`9C`E`!$?N``1B+H`<1@E`!.8/@'Y>"T`XS@E`>9X
M+0#S."0`>#`D`.8X)=^F`8``$(`^`,4P+0#0@"T`#\@\``\Q>``/?OH`PC`D
M,>\`'P#/>"4`$S>X`!.8N@#3,"4`\#@M``:`/``9R#X`$(`^`&9P)0`#B#P!
MV7`D`'`8)`'#<"7?HP&(`.\X+0!E&"T`>,`M``>0/``'&7@`!S[Z`&(8)##G
M`!\`9S@E`!D?N``9R+H`>1@E`!*0/@'8<"T`PS`E`<=P+0#2,"0`<#@D`,<P
M)=^G`9``$8@^`.4X+0#QB"T`#G@\``XY>``.=OH`XC@D,<X`'P#N<"4`$C^X
M`!*0N@#R."4`T3`M``>(/``/>#X`$8@^`&?`)0`#R#P##\`D`'$8)`,#P"7?
MHP&8`,XP+0!E&"T`<(`M``:8/``&&7@`!C;Z`&(8)##&`!\`9C`E``\?N``/
M>+H`;Q@E`!.8/@,0P"T`XS@E`P;`+0#S."0`<3`D`.8X)=^F`:``&<@^`,4P
M+0#9R"T`&(`\`!@Q>``8QOH`PC`D,Q@`'P#8P"4`$S>X`!.8N@#3,"4`^3@M
M``;(/``0@#X`&<@^`&9P)0`#>#P!T'`D`'D8)`'#<"7?HP&H`/@X+0!E&"T`
M<8@M``>0/``'&7@`!S[Z`&(8)##G`!\`9S@E`!`?N``0@+H`<!@E`!*0/@'1
M<"T`PS`E`<=P+0#2,"0`>3@D`,<P)=^G`;``#W@^`.4X+0#O>"T`#H@\``XY
M>``.=OH`XC@D,<X`'P#N<"4`$C^X`!*0N@#R."4`SS`M``=X/``1B#X`#W@^
M`&?`)0`#@#P#$<`D`&\8)`,#P"7?HP&X`,XP+0!E&"T`><@M``:8/``&&7@`
M$7>X``8V^@`1B+H!T7`E`&(8)##&`!\`$Y@^`&8P)0#N&"4`<Q@D`<\X)`!G
M&"7?IP'``QG`+0,&,"T`Y3@M`!"`/@#P@"T`!CEX`.+()``&/OHPYP`?`R<X
M)0`&P#P`<!@M`!,WN``3F+H`TS`E`&<8+=^G`<@`!H`\`!C`/@`0@#X!QL@E
M`.4X+0#O>"T`#H@\``.0/`'0<"0#.,@D``,Y>``#'OH`XC@D`R[()3!C`!\`
MXQ@E`R_(+0,CR"W?HP'0`!A_N``8P+H!^'@E`&48+0`1B#X`$I`^`,\X)0!Q
MB"T`&7`\`!D9>``9SOH!\#`D`&(8)`#R."0S.0`?`'G()0#F."4`$A^X`!*0
MN@!R&"4`\3@M`/DX+0`#R#P`#G`^`!G(/@'C,"4`#\`\`,XP)`'Y>"0`SS`E
MWZ\!V``'B#P!Y7@M`?"`+0`'>7@`!S[Z`>)X)##G`!\!YS@E``<X/`#0,"T`
M!S@^`,>@+0`.-[@`#G"Z`,XP)0`1B#X`9A@E`-EP)`!Q&"0`;A@EWZX!X``8
MP#X`%'@\`<4H+0`/>#X`N"@M`&4H+0`/F7@`#Q[Z`F.8)0`3F#P`$Y@^/`-E
M,0"SF"T`$8>XWZ4!Z``1B+ID8V#K``,8>`(1@"4`$Y`\`!*0/@"C*"T`!C@\
M`-`P)@"YR"T`$G;Z`-0P)@`2*7@`KB@E``8P/``/C[@`!C`^``]XN@`%*#P"
M+X@E`-DP+0`%*#X`Q3`MWZX!\`(1*"8`LR@F`<-P+0`&H#P`!S@^``4H/``4
MH#X!QS@M``4H/@"G*"T`%,%X`!0^^@,'P"4`$G^X`!*0N@'R>"4`&,`\`B\X
M)@`8P#[?K@'X`+@H+0#F,"8`$(`\``7(/`'#<"T`$(`^``8P/``9R#X!T'`M
M``8P/@`9/OH!QC`M`!EQ>`''<"4`%)>X`!2@N@)4D"4`#G`\`?(X)@`.<#[?
MN`(``,XP+0#E*"8`$8@\``:8/`,#P"T`$8@^``4H/``3F#X#$<`M``4H/@,%
MP"T`$SEX`!,N^@#E."4`&8>X`!G(N@(9@"4`!S@\`E`H)@`'.#[?K@((`P?`
M+0"F,"8`#W@\`!B(/`'#<"T`#W@^``8P/``1B#X!SW`M``8P/@'&<"T`$2EX
M`!$V^@"F*"4`!2@\``4H/@'%<"T`$\^X`!.8N@,SR"4`#J`\WZ<"$``4H#X"
M&2@F`!*0/`#C."T`$I`^`+C`)@`4>7@`%"[Z`/(X+0'E>"4`$9>X`!C`/``1
MB+H"49`E`!C`/@`/>#P#,C`F`/@X+0`/>#[?I0(8`.\X+0#.<"8`$(`\``>8
M/`"C*"T`$(`^``YP/``3F#X`L"@M``YP/@"N*"T`$S%X`!-V^@#.,"4`!C`\
M``8P/@"F*"T`%(>X`!2@N@(4@"4`!8@\`!&(/@)0,";?KP(@`,<X)@`1<7@`
M$3;Z`!G(/`'C>"T`&<@^`<9P)0`3Q[@`!S@\`!.8N@,3P"4!^7@M``<X/@`.
M<#P!YW@M``YP/@(8.";?I@(H`>YX+0#E*"8`$I`\``_(/`##,"T`$I`^``4H
M/``9R#X`TC`M``4H/@#%,"T`&3EX`!DN^@#E."4`!S@\``<X/@#',"T`$9>X
M`!&(N@)1D"4`!I@\`!.8/@,2*";?K@(P`!,^^@"O>"8`$(`\`!,I>`'#<"T`
M$(`^`*<H)0`/>#P!T'`M``]X/@`%*#P!SW`M``4H/@'%<"T`&8>X`!G(N@(9
M@"4`#H@\WZ<".``1B#X"4"@F`!C`/`#C."T`&,`^`*8P)@`1>7@`$2[Z`/@X
M+0'E>"4`$\>X``8P/``3F+H#$\`E``8P/@`/>#P`YC@M``]X/@(8,";?I0)`
M`.\X+0#.<"8`$I`\``?(/`"C*"T`$I`^``YP/``9R#X`LB@M``YP/@"N*"T`
M&3%X`!EV^@#.,"4`!C`\``8P/@"F*"T`$9^X`!&(N@)QF"4`!:`\WZ\"2``4
MH#X#$S`F`!"`/`'C>"T`$(`^`,<X)@`4<7@`%#;Z`?!X+0'&<"4`&8>X``<X
M/``9R+H"&8`E``<X/@`.<#P!YW@M``YP/@)P.";?I@)0`>YX+0#E*"8`&,`\
M``^0/`##,"T`&,`^``4H/``2D#X`V#`M``4H/@#%,"T`$CEX`!(N^@#E."4`
M!S@\``<X/@#',"T`%,^X`!2@N@,TR"4`!H@\`!&(/@(9*";?K@)8`*]X)@`1
MP7@`$2[Z`!.8/`'#<"T`$Y@^`P7`)0`/>#P!TW`M``]X/@`8P#P!SW`M`!C`
M/@'8<"T`$I^X`!*0N@)RF"4`#J`\`!2@/@,S*";?IP)@`*8P)@`4>7@`%"[Z
M`!"`/`#C."T`$(`^`>5X)0`&,#P`\#@M``8P/@`/>#P`YC@M``]X/@#O."T`
M$8>X`!&(N@(1@"4`!Y`\`!*0/@)P*";?N`)H`!(V^@"N<"8`&<@\`!(I>`,#
MP"T`&<@^`*8H)0`.<#P#&<`M``YP/@`%*#P##L`M``4H/@,%P"T`%,^X`!2@
MN@,TR"4`&(@\`!&(/@(9*";?KP)P`!$V^@"G."8`$Y@\`!$I>`'C>"T`IB@E
M`!.8/@`'.#P`!S@^`!(WN`'S>"T`!2@\`!*0N@#2,"4!YW@M``4H/@'E>"T#
M)G`FWZ4">`'8P"8`$(`\``\X/`"C*"T`$(`^`!C`/``'.#X`&,`^`+`H+0"X
M*"T`!W;Z``?!>`,.P"4`N,`M`!%WN-^E`H``$8BZ`=%P)0"C&"T`SB@F`*]X
M)@`9R#P`&"EX`*(0)`!M&"T`&<@^``]X/``8+OH`>1@M``]X/C"E`!\`;Q@M
M`$40)0!B$"T``A`\``(0/OR"````!Q>X``<XN@!'$"4`2$`M`PM8+0'*4"T`
MS&`MWZ,"B``+6#P`"$`\``I0/``,8#S=(@````M8/@`(0#X`"E`^``Q@/OR+
M``C\B``0_(H`&!!B``3\C``@WYF!&`,@^`D`````W[\"R-^\`L#?M0*XW[0"
ML-^S`JC?L@*@W[$"F-^P`I`#X``(9[T"T&>]__#_O```/!P``@.9X"UGG-<8
MWYF"H/^_``@#(/@))`0`@#P$9T5DA",!_$0``"0$=^<`!"1X9(2KB?Q$``@\
M!$Q=9(1N?P`$('C\1``0/`00,F2$5';\1``8/`0,/62$+A\`!"$X_$0`(/Q`
M`"C\0``PK$``>-^_``C?O````^``"&>]`!!GO?_`_[P`,/^Q``C_L```_[\`
M./^U`"C_M``@_[,`&/^R`!#<@P`H``80^`!#$"T``A`\/!P``@`"$#X#F>`M
M`$,8*V><UI``@(`E$&``!`#`B"7<@P`P9&,``?R#`##>`P`P_@(`*(X$`'@`
M$1=Z`&(0+?X"`#`0@``?9A(`."0"`$``1!`C`%$8*A!@``("(#`E`$`P)0)$
M("T`A1`K$$```P#`H"4`E!`M`*(`,P"D$"L00``"`*:8+0"3`#/?F8$X`R#X
M"0````".`@!X)`,`0`!4$"$40P`:K@(`>-^9@%@"`"`E9SD]\`,@^`D"-(@C
M`F`H)=^3@%AF%0!X9G,]\"HB`$#?F8$X$$``&`"R&"L"11`K$$```@)1$"T`
MH@`S$&``!`(@,"4`L1`M`D(`,P(@,"4#(/@)`D`@):X1`'C?OP`XW[P`,-^U
M`"C?M``@W[,`&-^R`!#?L0`(W[````/@``AGO0!`````-`)%$"L00``#`+40
M*Q1`__L`````$&``!&2T`$`"5!`K%$#_]@`````D!@!``D`@)0,@^`DF,?_`
M`F#()0,@^`D"`"`E$`#_TP*`*"5GO?_`_[P`,/^U`"C_LP`8_[$`"/^P``#_
MOP`X_[0`(/^R`!#<L@`H/!P``@`2$/H#F>`M,$(`/V><U-0`0!@E9+4`."1"
M``$"HQ@MWY.`6`"`B"4D!/^`W+0`,*!D```H0P`YWYF"N`"@@"4"HB`M%&``
M8V9S/?`D!@!``,(P(P,@^`D``"@E`F#()0,@^`D"`"`EWYF"N"0&`#@``"@E
M`J`@)0,@^`D``````!06.J("`'``%!0ZH@(`<0`4$CJB`@!R`!(6.J("`'0`
M$A0ZH@(`=0(`("4`$A(Z`F#():(4`'.B`@!V`R#X":(2`'?>`@``WYF!<``"
M%CJB(@``W@(```(`("4``A0ZHB(``=X"`````A(ZHB(``MX"``"B(@`#W@(`
M"``"%CJB(@`$W@(`"``"%#JB(@`%W@(`"``"$CJB(@`&W@(`"*(B``?>`@`0
M``(6.J(B``C>`@`0``(4.J(B``G>`@`0``(2.J(B``K>`@`0HB(`"]X"`!@`
M`A8ZHB(`#-X"`!@``A0ZHB(`#=X"`!@``A(ZHB(`#MX"`!BB(@`/W@(`(``"
M%CJB(@`0W@(`(``"%#JB(@`1W@(`(``"$CJB(@`2W@(`(`,@^`FB(@`3W[\`
M.-^\`##?M0`HW[0`(-^S`!C?L@`0W[$`"-^P```#X``(9[T`0"0&`#@`PC`C
M$`#_I@``*"4`````9[W_X/^\`!`\'``"`YG@+6><TL#_L```WY"`./^Q``C_
MOP`89A"OX"01___>&0``%S$`!M^_`!C?O``0W[$`"-^P```#X``(9[T`(`,@
M^`EF$/_X$`#_]MX9````````WYF`$`/@>"4#(/@)9!@`:]^9@!`#X'@E`R#X
M"608`&K?F8`0`^!X)0,@^`ED&`!GWYF`$`/@>"4#(/@)9!@`9M^9@!`#X'@E
M`R#X"608`&7?F8`0`^!X)0,@^`ED&`!DWYF`$`/@>"4#(/@)9!@`8]^9@!`#
MX'@E`R#X"608`&+?F8`0`^!X)0,@^`ED&`!AWYF`$`/@>"4#(/@)9!@`7]^9
M@!`#X'@E`R#X"608`%[?F8`0`^!X)0,@^`ED&`!=WYF`$`/@>"4#(/@)9!@`
M7-^9@!`#X'@E`R#X"608`%O?F8`0`^!X)0,@^`ED&`!:WYF`$`/@>"4#(/@)
M9!@`6=^9@!`#X'@E`R#X"608`%C?F8`0`^!X)0,@^`ED&`!7WYF`$`/@>"4#
M(/@)9!@`5M^9@!`#X'@E`R#X"608`%7?F8`0`^!X)0,@^`ED&`!4WYF`$`/@
M>"4#(/@)9!@`4]^9@!`#X'@E`R#X"608`%+?F8`0`^!X)0,@^`ED&`!1WYF`
M$`/@>"4#(/@)9!@`3]^9@!`#X'@E`R#X"608`$[?F8`0`^!X)0,@^`ED&`!-
MWYF`$`/@>"4#(/@)9!@`2]^9@!`#X'@E`R#X"608`$K?F8`0`^!X)0,@^`ED
M&`!)WYF`$`/@>"4#(/@)9!@`2-^9@!`#X'@E`R#X"608`$??F8`0`^!X)0,@
M^`ED&`!&WYF`$`/@>"4#(/@)9!@`1=^9@!`#X'@E`R#X"608`$/?F8`0`^!X
M)0,@^`ED&`!"WYF`$`/@>"4#(/@)9!@`0-^9@!`#X'@E`R#X"608`#W?F8`0
M`^!X)0,@^`ED&``\WYF`$`/@>"4#(/@)9!@`.]^9@!`#X'@E`R#X"608`#K?
MF8`0`^!X)0,@^`ED&``XWYF`$`/@>"4#(/@)9!@`-]^9@!`#X'@E`R#X"608
M`#;?F8`0`^!X)0,@^`ED&``UWYF`$`/@>"4#(/@)9!@`,M^9@!`#X'@E`R#X
M"608`#'?F8`0`^!X)0,@^`ED&``PWYF`$`/@>"4#(/@)9!@`+]^9@!`#X'@E
M`R#X"608`"W?F8`0`^!X)0,@^`ED&``LWYF`$`/@>"4#(/@)9!@`*]^9@!`#
MX'@E`R#X"608`"K?F8`0`^!X)0,@^`ED&``IWYF`$`/@>"4#(/@)9!@`*-^9
M@!`#X'@E`R#X"608`"??F8`0`^!X)0,@^`ED&``FWYF`$`/@>"4#(/@)9!@`
M)=^9@!`#X'@E`R#X"608`"0`````````````````````9[W_X/^\`!#_OP`8
M``````01``$``````X`0)3P<``(GG,Z(`Y_@+=^9@&`#(/@)`````-^\`!#?
MOP`8`^``"&>]`"````````````````!005)?5$U01$E2````````5$U01$E2
M``!414U01$E2`%1%35``````5$U0```````N`````````"XN````````)7,O
M)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L
M<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO)7,``````%!!4E]4
M14U0``````````!005)?4%)/1TY!344`````.@`````````O`````````"5S
M)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`````````
M`%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?
M0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!0
M05)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@``````
M``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````4$%2
M7T-,14%./0```````#$`````````3$1?3$E"4D%265]0051(`%-94U1%30``
M+W1M<`````!54T52`````%5315).04U%```````````E,#)X`````'!A<BT`
M````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P
M87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`
M```E<R5S=&5M<"TE=2TE=25S``````````!!4D=6`````!@`````````<&5R
M;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4P````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````"UE````````+2T```````!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O
M;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E
M;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*
M;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@
M)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D
M;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@
M)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H
M=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&
M2"P@)&UA9VEC7W!O<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ
M92`K(&QE;F=T:"@D4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H
M)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*
M;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@
M)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M
M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*
M;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PIP<FEN="`D9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D
M9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA
M;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO
M="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P
M87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO
M9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@
M/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD
M969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U
M:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G
M<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@
M;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T
M(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D
M9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#
M8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0[
M"GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T
M<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@
M*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS
M92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@
M)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X[
M"F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C
M;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*
M)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI
M.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#
M04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP
M<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M"GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z
M.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T
M('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M"F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E
M;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*
M9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@
M+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60[
M"F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H
M)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D[
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H
M;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD
M8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE
M>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E
M*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL
M97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M
M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A
M;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@
M)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@```````````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M``````````!P97)L>'-I+F,````````````````````O;&EB+VQD+6UU<VPM
M;6EP<S8T+7-F+G-O+C$`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````__________\``````````/______
M____``````````````````!B`````````&(0````````8A@```````!B(```
M`````&(H``````````#_____````````````````````````9<``````````
M`````````````````````````````````(``````````````````8;``````
M```8.````````!D````````"``````````&P6````````;.@```````!K_@`
M`````````````````!W4````````'L0```````$``````````"8,````````
M.*`````````FY````````"ZP````````+O@````````N/````````"A$````
M````63@```````!9P````````%M\````````+`P````````P#````````"K,
M````````*J````````&P0````````#TX````````79``````````````````
M````````````89````````!A@````````&%P````````86````````!A4```
M`````&%`````````83````````!A(````````&$0````````80``````````
M`````````&#P````````8.````````!@T````````&#`````````````````
M`````````````&"P````````8*````````!@D````````&"`````````````
M``````!@<````````&!@````````8%````````!@0```````````````````
M``````````!@,```````````````````8"````````!@$```````````````
M````8`````````!?\````````%_@````````7]````````!?P````````%^P
M````````7Z```````````````````%^0````````7X````````!?<```````
M````````````7V````````!?4````````%]`````````7S````````!?(```
M`````%\0````````7P````````!>\````````%[@````````7M````````!>
MP````````%ZP````````7J````````!>D````````%Z`````````````````
M``!><````````%Y@````````7E````````!>0````````%XP````````7B``
M``````!>$`````````````````````````````!>`````````%WP```````!
MLZ!'0T,Z("A!;'!I;F4@.2XS+C`I(#DN,RXP```````=`)````#____X````
M```````````0````'0```!\``!\@D'\``/____@``````````````%`````=
M````'P``(!R0`0``____^```````````````,````!T````?```@A)`/``#_
M___X``````````````!0````'0```!\``"%`D'\``/____@`````````````
M`&`````=````'P``(X20_P``____^``````````````!0````!T````?```E
M7)`#``#____X``````````````$`````'0```!\``"8,D````/____@`````
M`````````!`````=````'P``)F20`0``____^```````````````(````!T`
M```?```FY)`/``#____X`````````````"!@````'0```!\``"@L````````
M```````````````````````=````'P``*$30_P``____^``````````````1
M4````!T````?```JH```````````````````````````````'0```!\``"K,
MD`$``/____@``````````````"`````=````'P``+`R0?P``____^```````
M````````@````!T````?```N/)`!``#____X```````````````@````'0``
M`!\``"ZPD````/____@``````````````!`````=````'P``+OB0#P``____
M^```````````````,````!T````?```P#-#_``#____X`````````````('P
M````'0```!\``#B@T/\``/____@``````````````'`````=````'P``/3B0
M`P``____^```````````````(````!T````?```9`)`/``#____X````````
M``````!0````'0```!\``#WPD#\``/____@``````````````M`````=````
M'P``63B0````____^```````````````$````!T````?``!9P)`_``#____X
M``````````````!`````'0```!\``%M\D#\``/____@``````````````$``
M```=````'T$````/9VYU``$````'!`,`+G-H<W1R=&%B`"Y-25!3+F%B:69L
M86=S`"Y-25!3+F]P=&EO;G,`+F1Y;F%M:6,`+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YR96PN9'EN`"YI;FET`"YT97AT`"Y-25!3+G-T=6)S`"YF:6YI`"YR
M;V1A=&$`+FEN=&5R<``N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N9&%T80`N
M<FQD7VUA<``N9V]T`"YS9&%T80`N8G-S`"YC;VUM96YT`"YP9'(`+F=N=2YA
M='1R:6)U=&5S````````````````````````````````````````````````
M```````````````````````````````````````````+<```*@`````````"
M`````````C@````````".``````````8````````````````````"```````
M```8````&G````T`````"````@````````)0`````````E`````````!&```
M``````````````````@``````````0```"@````&``````````(````````#
M:`````````-H`````````@`````&```````````````(`````````!`````Q
M````!0`````````"````````!6@````````%:`````````,\````!0``````
M````````"``````````$````-P````L``````````@````````BH````````
M"*@````````*(`````8````"``````````@`````````&````#\````#````
M``````(````````2R````````!+(````````!+X````````````````````!
M``````````````!'````"0`````````"````````%X@````````7B```````
M``"`````!0``````````````"``````````0````4`````$`````````!@``
M`````!@X````````&#@`````````:`````````````````````@`````````
M`````%8````!``````````8````````9`````````!D`````````1/``````
M``````````````$```````````````!<`````0`````````&````````7?``
M``````!=\`````````/`````````````````````"```````````````:```
M``$`````````!@```````&&P````````8;``````````1```````````````
M``````@``````````````&X````!``````````(```````!B`````````&(`
M````````/G`````````````````````0``````````````!V`````0``````
M```"````````H'````````"@<``````````<`````````````````````0``
M````````````?@````$``````````P```````:_<````````K]P`````````
M!`````````````````````0``````````````(@````!``````````,`````
M``&OX````````*_@`````````!`````````````````````(````````````
M``"/`````0`````````#```````!K_````````"O\``````````0````````
M````````````"```````````````E@````$``````````P```````;``````
M````L```````````4````````````````````!```````````````)P````!
M``````````,```````&P4````````+!0``````````@`````````````````
M```(``````````````"E`````0`````0```#```````!L&````````"P8```
M``````-`````````````````````$``````````(````J@````$`````$```
M`P```````;.@````````LZ``````````"`````````````````````@`````
M`````````+$````(``````````,```````&SL````````+.H````````$'``
M```````````````````0``````````````"V`````0`````````P````````
M``````````"SJ``````````:`````````````````````0`````````!````
MOP````$`````````````````````````````L\0````````#0```````````
M``````````0``````````````,1O___U````````````````````````````
M`+<$`````````!`````````````````````!```````````````!`````P``
M``````````````````````````"W%`````````#4````````````````````
)`0``````````
